require "import"
import "android.widget.*"
import "android.content.*"
import "android.net.Uri"

-- Layout for the main dialog
layout = {
    LinearLayout,
    orientation = "vertical",
    layout_width = "fill",
    layout_height = "fill",
    padding = "16dp",
    {
        TextView,
        text = "WhatsApp Chat Link Generator",
        layout_width = "fill",
        layout_height = "wrap",
        gravity = "center",
        textSize = 24,
        padding = "16dp",
    },
    {
        TextView,
        text = "Enter your phone number (with country code) and a message:",
        layout_width = "fill",
        layout_height = "wrap",
        textSize = 16,
        padding = "8dp",
    },
    {
        EditText,
        id = "phoneInput",
        hint = "Phone number (e.g., 919876543210)",
        layout_width = "fill",
        layout_height = "wrap",
    },
    {
        EditText,
        id = "messageInput",
        hint = "Message (optional)",
        layout_width = "fill",
        layout_height = "wrap",
    },
    {
        Button,
        id = "generateButton",
        text = "Generate WhatsApp Link",
        layout_width = "fill",
        layout_height = "wrap",
        onClick = function()
            generateLink()
        end
    },
    {
        TextView,
        id = "outputLabel",
        text = "Generated Link:",
        layout_width = "fill",
        layout_height = "wrap",
        textSize = 16,
        visibility = 8, -- Initially hidden
        paddingTop = "8dp",
    },
    {
        TextView,
        id = "outputLink",
        text = "",
        layout_width = "fill",
        layout_height = "wrap",
        textColor = "#0000FF",
        padding = "8dp",
        textSize = 14,
        visibility = 8, -- Initially hidden
    },
    {
        LinearLayout,
        layout_width = "fill",
        layout_height = "wrap",
        orientation = "horizontal",
        gravity = "center",
        {
            Button,
            id = "copyButton",
            text = "Copy Link",
            layout_width = "wrap",
            layout_height = "wrap",
            visibility = 8, -- Initially hidden
            onClick = function()
                copyLink()
            end
        },
        {
            Button,
            id = "shareButton",
            text = "Share Link",
            layout_width = "wrap",
            layout_height = "wrap",
            visibility = 8, -- Initially hidden
            layout_marginLeft = "16dp",
            onClick = function()
                shareLink()
            end
        },
        {
            Button,
            id = "openButton",
            text = "Open Link in WhatsApp",
            layout_width = "wrap",
            layout_height = "wrap",
            visibility = 8, -- Initially hidden
            layout_marginLeft = "16dp",
            onClick = function()
                openGeneratedLink()
            end
        }
    }
}

-- Main dialog
dlg = LuaDialog(this)
dlg.View = loadlayout(layout)
dlg.setTitle("WhatsApp Chat Link Generator")
dlg.setButton("Close", nil)
dlg.show()

-- Variables to hold the generated link
local generatedLink = ""

-- Function to generate the WhatsApp link
function generateLink()
    local phone = phoneInput.text
    local message = messageInput.text or ""

    if phone == "" then
        showToast("Please enter a phone number.")
        return
    end

    local encodedMessage = Uri.encode(message)
    generatedLink = "https://wa.me/" .. phone .. "?text=" .. encodedMessage

    -- Update the output
    outputLabel.setVisibility(0) -- Show label
    outputLink.setVisibility(0) -- Show link
    outputLink.text = generatedLink

    copyButton.setVisibility(0) -- Show copy button
    shareButton.setVisibility(0) -- Show share button
    openButton.setVisibility(0) -- Show open button

    showToast("WhatsApp link generated.")
end

-- Function to open the generated link directly
function openGeneratedLink()
    if generatedLink == "" then
        showToast("Please generate a link first.")
        return
    end
    local intent = Intent(Intent.ACTION_VIEW)
    intent.setPackage("com.whatsapp")
    intent.setData(Uri.parse(generatedLink))
    pcall(function()
        this.startActivity(intent)
    end)
end

-- Function to copy the generated link to the clipboard
function copyLink()
    if generatedLink == "" then
        showToast("Please generate a link first.")
        return
    end
    local clipboard = this.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = ClipData.newPlainText("WhatsApp Link", generatedLink)
    clipboard.setPrimaryClip(clip)
    showToast("Link copied to clipboard.")
end

-- Function to share the generated link
function shareLink()
    if generatedLink == "" then
        showToast("Please generate a link first.")
        return
    end
    local intent = Intent(Intent.ACTION_SEND)
    intent.setType("text/plain")
    intent.putExtra(Intent.EXTRA_TEXT, generatedLink)
    pcall(function()
        this.startActivity(Intent.createChooser(intent, "Share via"))
    end)
end

-- Helper function to show toast messages
function showToast(message)
    Toast.makeText(this, message, Toast.LENGTH_SHORT).show()
end